@@ -1,5 +1,5 @@
 /* Test of test whether an UTF-8 string is already case-folded.
-   Copyright (C) 2009-2022 Free Software Foundation, Inc.
+   Copyright (C) 2009-2024 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -46,5 +46,5 @@ main ()
   test_ascii (u8_is_casefolded);
   test_nonascii (u8_is_casefolded);
 
-  return 0;
+  return test_exit_status;
 }
