@@ -1,9 +1,9 @@
 /* Test of normalization insensitive comparison of UTF-8 strings.
-   Copyright (C) 2009-2022 Free Software Foundation, Inc.
+   Copyright (C) 2009-2024 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 3 of the License, or
+   the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -112,5 +112,5 @@ main ()
   test_ascii (u8_normcmp, UNINORM_NFD);
   test_nonascii (u8_normcmp);
 
-  return 0;
+  return test_exit_status;
 }
